==> ugene_1.7.1%2Brepack.orig.tar.gz: ugene-1.7.1/src/plugins/dna_graphpack/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>GB2::BaseContentGraphFactory</name>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="15"/>
        <source>ag_content_graph</source>
        <translation>AG содержание (%)</translation>
    </message>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="17"/>
        <source>gc_content_graph</source>
        <translation>GC содержание (%)</translation>
    </message>
</context>
<context>
    <name>GB2::CumulativeSkewGraphFactory</name>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="18"/>
        <source>at_cumulative_skew_not_optimal_version</source>
        <translation>AT Cumulative Skew</translation>
    </message>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="20"/>
        <source>gc_cumulative_skew_not_optimal_version</source>
        <translation>GC Cumulative Skew</translation>
    </message>
</context>
<context>
    <name>GB2::DNAGraphPackPlugin</name>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="28"/>
        <source>dna_graphpack_plugin</source>
        <translation>DNA GraphPack</translation>
    </message>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="28"/>
        <source>dna_graphpack_plugin_desc</source>
        <translation>Этот плагин содержит набор контекстных графиков для DNA последовательностей</translation>
    </message>
</context>
<context>
    <name>GB2::DeviationGraphFactory</name>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="14"/>
        <source>at_deviation_graph</source>
        <translation>AT отклонение (A-T)/(A+T)</translation>
    </message>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="16"/>
        <source>gc_deviation_graph</source>
        <translation>GC отклонение (G-C)/(G+C)</translation>
    </message>
</context>
<context>
    <name>GB2::EntropyGraphFactory</name>
    <message>
        <location filename="../src/EntropyAlgorithm.cpp" line="22"/>
        <source>informational_entropy</source>
        <translation>Информационная энтропия</translation>
    </message>
</context>
<context>
    <name>GB2::GraphMenuAction</name>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="114"/>
        <source>graph_menu</source>
        <translation>Графики</translation>
    </message>
</context>
<context>
    <name>GB2::KarlinGraphFactory</name>
    <message>
        <location filename="../src/KarlinSignatureDifferenceGraph.cpp" line="16"/>
        <source>karlin_signature_difference_graph</source>
        <translation>Karlin Signature Difference</translation>
    </message>
</context>
</TS>

==> ugene_1.9.8%2Brepack.orig.tar.gz: ugene-1.9.8/src/plugins/dna_graphpack/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>U2::BaseContentGraphFactory</name>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="15"/>
        <source>ag_content_graph</source>
        <translation>AG содержание (%)</translation>
    </message>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="17"/>
        <source>gc_content_graph</source>
        <translation>GC содержание (%)</translation>
    </message>
</context>
<context>
    <name>U2::CumulativeSkewGraphFactory</name>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="18"/>
        <source>at_cumulative_skew_not_optimal_version</source>
        <translation>AT Cumulative Skew</translation>
    </message>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="20"/>
        <source>gc_cumulative_skew_not_optimal_version</source>
        <translation>GC Cumulative Skew</translation>
    </message>
</context>
<context>
    <name>U2::DNAGraphPackPlugin</name>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="28"/>
        <source>dna_graphpack_plugin</source>
        <translation>DNA GraphPack</translation>
    </message>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="28"/>
        <source>dna_graphpack_plugin_desc</source>
        <translation>Этот плагин содержит набор контекстных графиков для DNA последовательностей</translation>
    </message>
</context>
<context>
    <name>U2::DeviationGraphFactory</name>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="14"/>
        <source>at_deviation_graph</source>
        <translation>AT отклонение (A-T)/(A+T)</translation>
    </message>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="16"/>
        <source>gc_deviation_graph</source>
        <translation>GC отклонение (G-C)/(G+C)</translation>
    </message>
</context>
<context>
    <name>U2::EntropyGraphFactory</name>
    <message>
        <location filename="../src/EntropyAlgorithm.cpp" line="22"/>
        <source>informational_entropy</source>
        <translation>Информационная энтропия</translation>
    </message>
</context>
<context>
    <name>U2::GraphMenuAction</name>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="114"/>
        <source>graph_menu</source>
        <translation>Графики</translation>
    </message>
</context>
<context>
    <name>U2::KarlinGraphFactory</name>
    <message>
        <location filename="../src/KarlinSignatureDifferenceGraph.cpp" line="16"/>
        <source>karlin_signature_difference_graph</source>
        <translation>Karlin Signature Difference</translation>
    </message>
</context>
</TS>
